# eps-spine-shared

A library to hold code shared by the NHS England Electronic Prescriptions Service and Spine systems.

## Overview

This library provides shared functionality and utilities used across EPS (Electronic Prescription Service) and Spine systems. This includes validations, data access prescriptions and business logic.

## Project Structure

```
eps-spine-shared/
├── src/
│   └── eps_spine_shared/     # Main library code
|   └── README.md             # Developer readme
├── tests/                    # Test files
├── CODE_OF_CONDUCT.md        # Developer code of conduct
├── CONTRIBUTING.md           # Guide to contributing
├── pyproject.toml            # Project configuration
├── LICENSE                   # Licensing information
├── Makefile                  # Build automation
└── README.md                 # This file
```

## Contributing

Contributions to this project are welcome from anyone, providing that they conform to the [guidelines for contribution](https://github.com/NHSDigital/eps-spine-shared/blob/main/CONTRIBUTING.md) and the [community code of conduct](https://github.com/NHSDigital/eps-spine-shared/blob/main/CODE_OF_CONDUCT.md).

### Licensing

This code is dual licensed under the MIT license and the OGL (Open Government License). Any new work added to this repository must conform to the conditions of these licenses. In particular this means that this project may not depend on GPL-licensed or AGPL-licensed libraries, as these would violate the terms of those libraries' licenses.

See [here](https://github.com/NHSDigital/eps-spine-shared/blob/main/LICENSE) for more information.

The contents of this repository are protected by Crown Copyright (C).
